@@ -6,12 +6,13 @@ from .mappers.python import (
     PythonFunction,
     PythonClass,
     PythonMethod,
+    PythonProperty,
     PythonData,
     PythonAttribute,
     PythonException,
 )
 
-# pylint: disable=attribute-defined-outside-init,no-self-use,unused-argument
+# pylint: disable=attribute-defined-outside-init,unused-argument
 
 
 class AutoapiDocumenter(autodoc.Documenter):
@@ -78,7 +79,7 @@ class AutoapiDocumenter(autodoc.Documenter):
         elif not self.options.inherited_members:
             children = (child for child in children if not child[1].inherited)
 
-        return False, sorted(children)
+        return False, children
 
 
 class _AutoapiDocstringSignatureMixin:  # pylint: disable=too-few-public-methods
@@ -92,7 +93,7 @@ class _AutoapiDocstringSignatureMixin:  # pylint: disable=too-few-public-methods
         if self.retann is None:
             self.retann = self.object.return_annotation
 
-        return super(_AutoapiDocstringSignatureMixin, self).format_signature(**kwargs)
+        return super().format_signature(**kwargs)
 
 
 class AutoapiFunctionDocumenter(
@@ -129,7 +130,7 @@ class AutoapiDecoratorDocumenter(
         if self.args is None:
             self.args = self.format_args(**kwargs)
 
-        return super(AutoapiDecoratorDocumenter, self).format_signature(**kwargs)
+        return super().format_signature(**kwargs)
 
     def format_args(self, **kwargs):
         to_format = self.object.args
@@ -169,8 +170,8 @@ class AutoapiClassDocumenter(
 
             # TODO: Change sphinx to allow overriding of getting base names
             if self.object.bases:
-                bases = [":class:`{}`".format(base) for base in self.object.bases]
-                self.add_line("   " + "Bases: {}".format(", ".join(bases)), sourcename)
+                bases = ", ".join(f":class:`{base}`" for base in self.object.bases)
+                self.add_line(f"   Bases: {bases}", sourcename)
 
 
 class AutoapiMethodDocumenter(
@@ -188,12 +189,15 @@ class AutoapiMethodDocumenter(
         return "(" + self.object.args + ")"
 
     def import_object(self):
-        result = super(AutoapiMethodDocumenter, self).import_object()
+        result = super().import_object()
 
         if result:
             self.parent = self._method_parent
-            if self.object.method_type != "method":
-                # document class and static members before ordinary ones
+            if "staticmethod" in self.object.properties:
+                # document static members before ordinary ones
+                self.member_order = self.member_order - 2
+            elif "classmethod" in self.object.properties:
+                # document class members before ordinary ones but after static ones
                 self.member_order = self.member_order - 1
 
         return result
@@ -209,25 +213,31 @@ class AutoapiMethodDocumenter(
             "staticmethod",
         ):
             if property_type in self.object.properties:
-                self.add_line("   :{}:".format(property_type), sourcename)
+                self.add_line(f"   :{property_type}:", sourcename)
 
 
-class AutoapiPropertyDocumenter(
-    AutoapiMethodDocumenter, AutoapiDocumenter, autodoc.PropertyDocumenter
-):
+class AutoapiPropertyDocumenter(AutoapiDocumenter, autodoc.PropertyDocumenter):
     objtype = "apiproperty"
-    directivetype = "method"
-    # Always prefer AutoapiDocumenters
-    priority = autodoc.MethodDocumenter.priority * 100 + 100 + 1
+    directivetype = "property"
+    priority = autodoc.PropertyDocumenter.priority * 100 + 100
 
     @classmethod
     def can_document_member(cls, member, membername, isattr, parent):
-        return isinstance(member, PythonMethod) and "property" in member.properties
+        return isinstance(member, PythonProperty)
 
     def add_directive_header(self, sig):
-        super(AutoapiPropertyDocumenter, self).add_directive_header(sig)
+        autodoc.ClassLevelDocumenter.add_directive_header(self, sig)
+
         sourcename = self.get_sourcename()
-        self.add_line("   :property:", sourcename)
+        if self.options.annotation and self.options.annotation is not autodoc.SUPPRESS:
+            self.add_line(f"   :type: {self.options.annotation}", sourcename)
+
+        for property_type in (
+            "abstractmethod",
+            "classmethod",
+        ):
+            if property_type in self.object.properties:
+                self.add_line(f"   :{property_type}:", sourcename)
 
 
 class AutoapiDataDocumenter(AutoapiDocumenter, autodoc.DataDocumenter):
@@ -245,13 +255,11 @@ class AutoapiDataDocumenter(AutoapiDocumenter, autodoc.DataDocumenter):
         if not self.options.annotation:
             # TODO: Change sphinx to allow overriding of object description
             if self.object.value is not None:
-                self.add_line(
-                    "   :annotation: = {}".format(self.object.value), sourcename
-                )
+                self.add_line(f"   :annotation: = {self.object.value}", sourcename)
         elif self.options.annotation is autodoc.SUPPRESS:
             pass
         else:
-            self.add_line("   :annotation: %s" % self.options.annotation, sourcename)
+            self.add_line(f"   :annotation: {self.options.annotation}", sourcename)
 
 
 class AutoapiAttributeDocumenter(AutoapiDocumenter, autodoc.AttributeDocumenter):
@@ -270,13 +278,11 @@ class AutoapiAttributeDocumenter(AutoapiDocumenter, autodoc.AttributeDocumenter)
         if not self.options.annotation:
             # TODO: Change sphinx to allow overriding of object description
             if self.object.value is not None:
-                self.add_line(
-                    "   :annotation: = {}".format(self.object.value), sourcename
-                )
+                self.add_line(f"   :annotation: = {self.object.value}", sourcename)
         elif self.options.annotation is autodoc.SUPPRESS:
             pass
         else:
-            self.add_line("   :annotation: %s" % self.options.annotation, sourcename)
+            self.add_line(f"   :annotation: {self.options.annotation}", sourcename)
 
 
 class AutoapiModuleDocumenter(AutoapiDocumenter, autodoc.ModuleDocumenter):
