@@ -74,14 +74,10 @@ class PythonMapperBase:
 
         ctx = {}
         try:
-            template = self.jinja_env.get_template(
-                "{language}/{type}.rst".format(language=self.language, type=self.type)
-            )
+            template = self.jinja_env.get_template(f"{self.language}/{self.type}.rst")
         except TemplateNotFound:
             # Use a try/except here so we fallback to language specific defaults, over base defaults
-            template = self.jinja_env.get_template(
-                "base/{type}.rst".format(type=self.type)
-            )
+            template = self.jinja_env.get_template(f"base/{self.type}.rst")
 
         ctx.update(**self.get_context_data())
         ctx.update(**kwargs)
@@ -104,10 +100,10 @@ class PythonMapperBase:
         """Object sorting comparison"""
         if isinstance(other, PythonMapperBase):
             return self.id < other.id
-        return super(PythonMapperBase, self).__lt__(other)
+        return super().__lt__(other)
 
     def __str__(self):
-        return "<{cls} {id}>".format(cls=self.__class__.__name__, id=self.id)
+        return f"<{self.__class__.__name__} {self.id}>"
 
     @property
     def short_name(self):
@@ -253,7 +249,7 @@ class SphinxMapperBase:
                             ):
                                 LOGGER.info(
                                     bold("[AutoAPI] ")
-                                    + darkgreen("Ignoring %s/%s" % (root, filename))
+                                    + darkgreen(f"Ignoring {root}/{filename}")
                                 )
                                 skip = True
 
@@ -314,7 +310,7 @@ class SphinxMapperBase:
             self.objects.items(),
             bold("[AutoAPI] ") + "Rendering Data... ",
             length=len(self.objects),
-            verbosity="INFO",
+            verbosity=1,
             stringify_func=(lambda x: x[0]),
         ):
             rst = obj.render()
@@ -323,7 +319,7 @@ class SphinxMapperBase:
 
             detail_dir = obj.include_dir(root=root)
             ensuredir(detail_dir)
-            path = os.path.join(detail_dir, "%s%s" % ("index", source_suffix))
+            path = os.path.join(detail_dir, f"index{source_suffix}")
             with open(path, "wb+") as detail_file:
                 detail_file.write(rst.encode("utf-8"))
 
