@@ -58,7 +58,7 @@ def get_full_import_name(import_from, name):
             import_from.modname, level=import_from.level
         )
 
-    return "{}.{}".format(module_name, partial_basename)
+    return f"{module_name}.{partial_basename}"
 
 
 def resolve_qualname(node, basename):
@@ -98,7 +98,7 @@ def resolve_qualname(node, basename):
             full_basename = assignment.qname()
             break
         if isinstance(assignment, astroid.nodes.AssignName):
-            full_basename = "{}.{}".format(assignment.scope().qname(), assignment.name)
+            full_basename = f"{assignment.scope().qname()}.{assignment.name}"
 
     if isinstance(node, astroid.nodes.Call):
         full_basename = re.sub(r"\(.*\)", "()", full_basename)
@@ -139,6 +139,9 @@ def _get_const_values(node):
                 break
         else:
             value = new_value
+
+        if isinstance(node, astroid.nodes.Tuple):
+            value = tuple(new_value)
     elif isinstance(node, astroid.nodes.Const):
         value = node.value
 
@@ -462,7 +465,8 @@ def _iter_args(args, annotations, defaults):
 
         name = arg.name
         if isinstance(arg, astroid.Tuple):
-            name = "({})".format(", ".join(x.name for x in arg.elts))
+            argument_names = ", ".join(x.name for x in arg.elts)
+            name = f"({argument_names})"
 
         yield (name, format_annotation(annotation), default)
 
@@ -479,7 +483,11 @@ def get_args_info(args_node):  # pylint: disable=too-many-branches,too-many-stat
         ]
 
     plain_annotations = args_node.annotations or ()
-    func_comment_annotations = args_node.parent.type_comment_args or ()
+
+    func_comment_annotations = args_node.parent.type_comment_args or []
+    if args_node.parent.type in ("method", "classmethod"):
+        func_comment_annotations = [None] + func_comment_annotations
+
     comment_annotations = args_node.type_comment_posonlyargs
     comment_annotations += args_node.type_comment_args or []
     comment_annotations += args_node.type_comment_kwonlyargs
@@ -559,6 +567,9 @@ def get_args_info(args_node):  # pylint: disable=too-many-branches,too-many-stat
             annotation_offset += 1
         result.append(("**", args_node.kwarg, annotation, None))
 
+    if args_node.parent.type in ("method", "classmethod") and result:
+        result.pop(0)
+
     return result
 
 
