@@ -15,11 +15,11 @@ def _format_args(args_info, include_annotations=True, ignore_self=None):
     for i, (prefix, name, annotation, default) in enumerate(args_info):
         if i == 0 and ignore_self is not None and name == ignore_self:
             continue
-        formatted = "{}{}{}{}".format(
-            prefix or "",
-            name or "",
-            ": {}".format(annotation) if annotation and include_annotations else "",
-            (" = {}" if annotation else "={}").format(default) if default else "",
+        formatted = (
+            (prefix or "")
+            + (name or "")
+            + (f": {annotation}" if annotation and include_annotations else "")
+            + ((" = {}" if annotation else "={}").format(default) if default else "")
         )
         result.append(formatted)
 
@@ -42,7 +42,7 @@ class PythonPythonMapper(PythonMapperBase):
     member_order = 0
 
     def __init__(self, obj, class_content="class", **kwargs):
-        super(PythonPythonMapper, self).__init__(obj, **kwargs)
+        super().__init__(obj, **kwargs)
 
         self.name = obj["name"]
         self.id = obj.get("full_name", self.name)
@@ -169,10 +169,10 @@ class PythonFunction(PythonPythonMapper):
 
     type = "function"
     is_callable = True
-    member_order = 40
+    member_order = 30
 
     def __init__(self, obj, **kwargs):
-        super(PythonFunction, self).__init__(obj, **kwargs)
+        super().__init__(obj, **kwargs)
 
         autodoc_typehints = getattr(self.app.config, "autodoc_typehints", "signature")
         show_annotations = autodoc_typehints != "none" and not (
@@ -217,15 +217,8 @@ class PythonMethod(PythonFunction):
     member_order = 50
 
     def __init__(self, obj, **kwargs):
-        super(PythonMethod, self).__init__(obj, **kwargs)
+        super().__init__(obj, **kwargs)
 
-        self.method_type = obj.get("method_type")
-        """The type of method that this object represents.
-
-        This can be one of: method, staticmethod, or classmethod.
-
-        :type: str
-        """
         self.properties = obj["properties"]
         """The properties that describe what type of method this is.
 
@@ -235,21 +228,44 @@ class PythonMethod(PythonFunction):
         """
 
     def _should_skip(self):  # type: () -> bool
-        skip = super(PythonMethod, self)._should_skip() or self.name in (
+        skip = super()._should_skip() or self.name in (
             "__new__",
             "__init__",
         )
         return self._ask_ignore(skip)
 
 
+class PythonProperty(PythonPythonMapper):
+    """The representation of a property on a class."""
+
+    type = "property"
+    member_order = 60
+
+    def __init__(self, obj, **kwargs):
+        super().__init__(obj, **kwargs)
+
+        self.annotation = obj["return_annotation"]
+        """The type annotation of this property.
+
+        :type: str or None
+        """
+        self.properties = obj["properties"]
+        """The properties that describe what type of property this is.
+
+        Can be any of: abstractmethod, classmethod
+
+        :type: list(str)
+        """
+
+
 class PythonData(PythonPythonMapper):
     """Global, module level data."""
 
     type = "data"
-    member_order = 10
+    member_order = 40
 
     def __init__(self, obj, **kwargs):
-        super(PythonData, self).__init__(obj, **kwargs)
+        super().__init__(obj, **kwargs)
 
         self.value = obj.get("value")
         """The value of this attribute.
@@ -272,7 +288,7 @@ class PythonAttribute(PythonData):
     """An object/class level attribute."""
 
     type = "attribute"
-    member_order = 10
+    member_order = 60
 
 
 class TopLevelPythonPythonMapper(PythonPythonMapper):
@@ -281,7 +297,7 @@ class TopLevelPythonPythonMapper(PythonPythonMapper):
     _RENDER_LOG_LEVEL = "VERBOSE"
 
     def __init__(self, obj, **kwargs):
-        super(TopLevelPythonPythonMapper, self).__init__(obj, **kwargs)
+        super().__init__(obj, **kwargs)
 
         self.top_level_object = "." not in self.name
         """Whether this object is at the very top level (True) or not (False).
@@ -335,10 +351,10 @@ class PythonClass(PythonPythonMapper):
     """The representation of a class."""
 
     type = "class"
-    member_order = 30
+    member_order = 20
 
     def __init__(self, obj, **kwargs):
-        super(PythonClass, self).__init__(obj, **kwargs)
+        super().__init__(obj, **kwargs)
 
         self.bases = obj["bases"]
         """The fully qualified names of all base classes.
@@ -395,7 +411,7 @@ class PythonClass(PythonPythonMapper):
 
             if constructor_docstring:
                 if self._class_content == "both":
-                    docstring = "{0}\n{1}".format(docstring, constructor_docstring)
+                    docstring = f"{docstring}\n{constructor_docstring}"
                 else:
                     docstring = constructor_docstring
 
@@ -409,6 +425,10 @@ class PythonClass(PythonPythonMapper):
     def methods(self):
         return self._children_of_type("method")
 
+    @property
+    def properties(self):
+        return self._children_of_type("property")
+
     @property
     def attributes(self):
         return self._children_of_type("attribute")
@@ -446,4 +466,4 @@ class PythonException(PythonClass):
     """The representation of an exception class."""
 
     type = "exception"
-    member_order = 20
+    member_order = 10
